@@ -1,4 +1,4 @@
-"graphinter" <- function(donnee, col.p, col.j, firstvar, lastvar=ncol(donnee), numr=2,numc=2) {
+graphinter <- function(donnee, col.p, col.j, firstvar, lastvar=ncol(donnee), numr=2,numc=2) {
 
      for (j in 1:(firstvar-1)) donnee[,j] <- as.factor(donnee[,j])
      nbprod <- length(levels(donnee[,col.p]))
@@ -6,17 +6,19 @@
      nbseance <- length(levels(donnee[,col.j]))
      labprod <- levels(donnee[,col.p])
           
-     moy <- matrix(0,nbprod,nbdesc)
-     for (p in 1:nbprod) moy[p,] <- mean(donnee[(donnee[,col.p]==levels(donnee[,col.p])[p]),(firstvar:lastvar)],na.rm=TRUE)
-     dimnames(moy) <- list(labprod,variable.names(donnee)[firstvar:lastvar])
+#     moy <- matrix(0,nbprod,nbdesc)
+#     for (p in 1:nbprod) moy[p,] <- mean(donnee[(donnee[,col.p]==levels(donnee[,col.p])[p]),(firstvar:lastvar)],na.rm=TRUE)
+	 moy <- matrix(unlist(by(donnee[,firstvar:lastvar,drop=FALSE],donnee[,col.p],apply,2,mean,na.rm=TRUE)),nrow=nlevels(donnee[,col.p]),byrow=TRUE)
+     dimnames(moy) <- list(labprod,colnames(donnee)[firstvar:lastvar])
 
      moyS <- array(0,c(nbprod,nbdesc,nbseance))
-     for (p in 1: nbprod) {
+#     for (p in 1: nbprod) {
          for (s in 1:nbseance) {
-           moyS[p,,s] <- mean(donnee[((donnee[,col.p]==levels(donnee[,col.p])[p])&(donnee[,col.j]==levels(donnee[,col.j])[s])),(firstvar:lastvar)],na.rm=TRUE) 
-         }
+#           moyS[p,,s] <- mean(donnee[((donnee[,col.p]==levels(donnee[,col.p])[p])&(donnee[,col.j]==levels(donnee[,col.j])[s])),(firstvar:lastvar)],na.rm=TRUE) 
+           moyS[,,s] <- matrix(unlist(by(donnee[donnee[,col.j]==levels(donnee[,col.j])[s],firstvar:lastvar,drop=FALSE],donnee[donnee[,col.j]==levels(donnee[,col.j])[s],col.p],apply,2,mean,na.rm=TRUE)),nrow=nlevels(donnee[,col.p]),byrow=TRUE)
+#         }
      }
-     dimnames(moyS) <- list(levels(donnee[,col.p]),variable.names(donnee)[firstvar:lastvar],levels(donnee[,col.j]))
+     dimnames(moyS) <- list(levels(donnee[,col.p]),colnames(donnee)[firstvar:lastvar],levels(donnee[,col.j]))
 
 mult <- nbdesc %/% (numr*numc)
 if (nbdesc==(nbdesc %/% (numr*numc))*(numr*numc)) mult=mult-1
@@ -34,7 +36,7 @@ for (m in 0:mult) {
                   for (i in 1:nrow(moy))  text(moy[i,nb],max(moyS[i,nb,],na.rm=TRUE),label=labprod[i], pos = 3,offset = 0.4, font = 1)
                 }
                 else  points(moy[order(moy[,nb]),nb],moyS[order(moy[,nb]),nb,s],type="o",pch=20,col=s)
-              title(variable.names(moy)[nb])
+              title(colnames(moy)[nb])
             }
         } 
     
